# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["PdfCreatePreviewParams"]


class PdfCreatePreviewParams(TypedDict, total=False):
    group: Required[str]

    is_signature_per_page: Required[int]

    signature_type: Required[int]

    signee_count: Required[int]
    """number of signers"""

    text: Required[str]
    """raw html"""

    footer: str

    footer_height: int

    header: str

    header_height: int

    pdfheader: bool
    """Set to true to use group default"""

    title: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["WebhookEventFilterEnum"]

WebhookEventFilterEnum: TypeAlias = Literal[
    "",
    "document.*",
    "document.created",
    "document.rejected",
    "document.finalPdfCreated",
    "recipient.*",
    "recipient.completed",
    "recipient.rejected",
    "recipient.emailOpened",
    "recipient.visiting",
    "recipient.bounced",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime

from .._models import BaseModel

__all__ = ["AttachmentResponse"]


class AttachmentResponse(BaseModel):
    created: Optional[datetime] = None

    description: Optional[str] = None

    filename: Optional[str] = None

    group: Optional[str] = None

    resource_uri: Optional[str] = None

    user: Optional[str] = None
    """resource_uri for user"""

    uuid: Optional[str] = None
    """id for attachment object"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .list_meta import ListMeta as ListMeta
from .template_pdf import TemplatePdf as TemplatePdf
from .timezone_enum import TimezoneEnum as TimezoneEnum
from .member_response import MemberResponse as MemberResponse
from .status_response import StatusResponse as StatusResponse
from .permissions_enum import PermissionsEnum as PermissionsEnum
from .group_list_params import GroupListParams as GroupListParams
from .member_list_params import MemberListParams as MemberListParams
from .signer_status_enum import SignerStatusEnum as SignerStatusEnum
from .user_create_params import UserCreateParams as UserCreateParams
from .user_update_params import UserUpdateParams as UserUpdateParams
from .attachment_response import AttachmentResponse as AttachmentResponse
from .group_create_params import GroupCreateParams as GroupCreateParams
from .group_list_response import GroupListResponse as GroupListResponse
from .group_update_params import GroupUpdateParams as GroupUpdateParams
from .invited_list_params import InvitedListParams as InvitedListParams
from .signer_reset_params import SignerResetParams as SignerResetParams
from .document_list_params import DocumentListParams as DocumentListParams
from .document_status_enum import DocumentStatusEnum as DocumentStatusEnum
from .member_create_params import MemberCreateParams as MemberCreateParams
from .member_list_response import MemberListResponse as MemberListResponse
from .template_list_params import TemplateListParams as TemplateListParams
from .invited_list_response import InvitedListResponse as InvitedListResponse
from .attachment_list_params import AttachmentListParams as AttachmentListParams
from .document_create_params import DocumentCreateParams as DocumentCreateParams
from .document_list_response import DocumentListResponse as DocumentListResponse
from .template_create_params import TemplateCreateParams as TemplateCreateParams
from .template_list_response import TemplateListResponse as TemplateListResponse
from .template_update_params import TemplateUpdateParams as TemplateUpdateParams
from .user_retrieve_response import UserRetrieveResponse as UserRetrieveResponse
from .document_preview_params import DocumentPreviewParams as DocumentPreviewParams
from .group_retrieve_response import GroupRetrieveResponse as GroupRetrieveResponse
from .templatepdf_list_params import TemplatepdfListParams as TemplatepdfListParams
from .attachment_list_response import AttachmentListResponse as AttachmentListResponse
from .attachment_upload_params import AttachmentUploadParams as AttachmentUploadParams
from .document_create_response import DocumentCreateResponse as DocumentCreateResponse
from .signer_retrieve_response import SignerRetrieveResponse as SignerRetrieveResponse
from .pdf_create_preview_params import PdfCreatePreviewParams as PdfCreatePreviewParams
from .pdf_field_validation_enum import PdfFieldValidationEnum as PdfFieldValidationEnum
from .templatepdf_create_params import TemplatepdfCreateParams as TemplatepdfCreateParams
from .templatepdf_list_response import TemplatepdfListResponse as TemplatepdfListResponse
from .webhook_event_filter_enum import WebhookEventFilterEnum as WebhookEventFilterEnum
from .document_retrieve_response import DocumentRetrieveResponse as DocumentRetrieveResponse
from .notification_list_response import NotificationListResponse as NotificationListResponse
from .status_retrieve_all_params import StatusRetrieveAllParams as StatusRetrieveAllParams
from .template_retrieve_response import TemplateRetrieveResponse as TemplateRetrieveResponse
from .signer_send_reminder_params import SignerSendReminderParams as SignerSendReminderParams
from .document_get_fields_response import DocumentGetFieldsResponse as DocumentGetFieldsResponse
from .status_retrieve_all_response import StatusRetrieveAllResponse as StatusRetrieveAllResponse
from .signer_retrieve_fields_response import SignerRetrieveFieldsResponse as SignerRetrieveFieldsResponse
from .subscribe_create_webhook_params import SubscribeCreateWebhookParams as SubscribeCreateWebhookParams
from .unsubscribe_delete_webhook_params import UnsubscribeDeleteWebhookParams as UnsubscribeDeleteWebhookParams
from .templatepdf_get_edit_link_response import TemplatepdfGetEditLinkResponse as TemplatepdfGetEditLinkResponse
from .signer_get_rejection_reason_response import SignerGetRejectionReasonResponse as SignerGetRejectionReasonResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import template_list_params, template_create_params, template_update_params
from .._types import Body, Omit, Query, Headers, NoneType, NotGiven, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.template_list_response import TemplateListResponse
from ..types.template_retrieve_response import TemplateRetrieveResponse

__all__ = ["TemplateResource", "AsyncTemplateResource"]


class TemplateResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> TemplateResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/legalesign/legalesign-rest-python#accessing-raw-response-data-eg-headers
        """
        return TemplateResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> TemplateResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/legalesign/legalesign-rest-python#with_streaming_response
        """
        return TemplateResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        group: str,
        latest_text: str,
        title: str,
        user: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """Create a new html/text template.

        This probably isn't the method you are looking
        for. You can use the 'text' attribute in /document/ to create and send your HTML
        as a signing document in one call.

        Args:
          latest_text: text/html for template

          user: assign to a user if not api user

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/template/",
            body=maybe_transform(
                {
                    "group": group,
                    "latest_text": latest_text,
                    "title": title,
                    "user": user,
                },
                template_create_params.TemplateCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def retrieve(
        self,
        template_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> TemplateRetrieveResponse:
        """
        Get text template

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not template_id:
            raise ValueError(f"Expected a non-empty value for `template_id` but received {template_id!r}")
        return self._get(
            f"/template/{template_id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TemplateRetrieveResponse,
        )

    def update(
        self,
        template_id: str,
        *,
        body: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Update text template

        Args:
          body: json with any fields to update

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not template_id:
            raise ValueError(f"Expected a non-empty value for `template_id` but received {template_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._patch(
            f"/template/{template_id}/",
            body=maybe_transform(body, template_update_params.TemplateUpdateParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def list(
        self,
        *,
        archive: str | Omit = omit,
        group: str | Omit = omit,
        limit: int | Omit = omit,
        offset: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> TemplateListResponse:
        """
        Get text templates

        Args:
          group: can be full resource_uri or only id

          limit: Length of dataset to return. Use with offset query to iterate through results.

          offset: Offset from start of dataset. Use with the limit query to iterate through
              dataset.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/template/",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "archive": archive,
                        "group": group,
                        "limit": limit,
                        "offset": offset,
                    },
                    template_list_params.TemplateListParams,
                ),
            ),
            cast_to=TemplateListResponse,
        )

    def archive(
        self,
        template_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """Archives a template (is recoverable, i.e.

        not fully deleted, if you need true
        data deletion contact us).

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not template_id:
            raise ValueError(f"Expected a non-empty value for `template_id` but received {template_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._delete(
            f"/template/{template_id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncTemplateResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncTemplateResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/legalesign/legalesign-rest-python#accessing-raw-response-data-eg-headers
        """
        return AsyncTemplateResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncTemplateResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/legalesign/legalesign-rest-python#with_streaming_response
        """
        return AsyncTemplateResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        group: str,
        latest_text: str,
        title: str,
        user: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """Create a new html/text template.

        This probably isn't the method you are looking
        for. You can use the 'text' attribute in /document/ to create and send your HTML
        as a signing document in one call.

        Args:
          latest_text: text/html for template

          user: assign to a user if not api user

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/template/",
            body=await async_maybe_transform(
                {
                    "group": group,
                    "latest_text": latest_text,
                    "title": title,
                    "user": user,
                },
                template_create_params.TemplateCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def retrieve(
        self,
        template_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> TemplateRetrieveResponse:
        """
        Get text template

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not template_id:
            raise ValueError(f"Expected a non-empty value for `template_id` but received {template_id!r}")
        return await self._get(
            f"/template/{template_id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TemplateRetrieveResponse,
        )

    async def update(
        self,
        template_id: str,
        *,
        body: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Update text template

        Args:
          body: json with any fields to update

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not template_id:
            raise ValueError(f"Expected a non-empty value for `template_id` but received {template_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._patch(
            f"/template/{template_id}/",
            body=await async_maybe_transform(body, template_update_params.TemplateUpdateParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def list(
        self,
        *,
        archive: str | Omit = omit,
        group: str | Omit = omit,
        limit: int | Omit = omit,
        offset: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> TemplateListResponse:
        """
        Get text templates

        Args:
          group: can be full resource_uri or only id

          limit: Length of dataset to return. Use with offset query to iterate through results.

          offset: Offset from start of dataset. Use with the limit query to iterate through
              dataset.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/template/",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "archive": archive,
                        "group": group,
                        "limit": limit,
                        "offset": offset,
                    },
                    template_list_params.TemplateListParams,
                ),
            ),
            cast_to=TemplateListResponse,
        )

    async def archive(
        self,
        template_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """Archives a template (is recoverable, i.e.

        not fully deleted, if you need true
        data deletion contact us).

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not template_id:
            raise ValueError(f"Expected a non-empty value for `template_id` but received {template_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._delete(
            f"/template/{template_id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class TemplateResourceWithRawResponse:
    def __init__(self, template: TemplateResource) -> None:
        self._template = template

        self.create = to_raw_response_wrapper(
            template.create,
        )
        self.retrieve = to_raw_response_wrapper(
            template.retrieve,
        )
        self.update = to_raw_response_wrapper(
            template.update,
        )
        self.list = to_raw_response_wrapper(
            template.list,
        )
        self.archive = to_raw_response_wrapper(
            template.archive,
        )


class AsyncTemplateResourceWithRawResponse:
    def __init__(self, template: AsyncTemplateResource) -> None:
        self._template = template

        self.create = async_to_raw_response_wrapper(
            template.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            template.retrieve,
        )
        self.update = async_to_raw_response_wrapper(
            template.update,
        )
        self.list = async_to_raw_response_wrapper(
            template.list,
        )
        self.archive = async_to_raw_response_wrapper(
            template.archive,
        )


class TemplateResourceWithStreamingResponse:
    def __init__(self, template: TemplateResource) -> None:
        self._template = template

        self.create = to_streamed_response_wrapper(
            template.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            template.retrieve,
        )
        self.update = to_streamed_response_wrapper(
            template.update,
        )
        self.list = to_streamed_response_wrapper(
            template.list,
        )
        self.archive = to_streamed_response_wrapper(
            template.archive,
        )


class AsyncTemplateResourceWithStreamingResponse:
    def __init__(self, template: AsyncTemplateResource) -> None:
        self._template = template

        self.create = async_to_streamed_response_wrapper(
            template.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            template.retrieve,
        )
        self.update = async_to_streamed_response_wrapper(
            template.update,
        )
        self.list = async_to_streamed_response_wrapper(
            template.list,
        )
        self.archive = async_to_streamed_response_wrapper(
            template.archive,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime

from .._models import BaseModel

__all__ = ["TemplateRetrieveResponse"]


class TemplateRetrieveResponse(BaseModel):
    archive: Optional[bool] = None

    created: Optional[datetime] = None

    group: Optional[str] = None

    has_fields: Optional[bool] = None

    latest_text: Optional[str] = None

    modified: Optional[datetime] = None

    resource_uri: Optional[str] = None

    signee_count: Optional[int] = None

    title: Optional[str] = None

    user: Optional[str] = None

    uuid: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import pdf_create_preview_params
from .._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    BinaryAPIResponse,
    AsyncBinaryAPIResponse,
    StreamedBinaryAPIResponse,
    AsyncStreamedBinaryAPIResponse,
    to_custom_raw_response_wrapper,
    to_custom_streamed_response_wrapper,
    async_to_custom_raw_response_wrapper,
    async_to_custom_streamed_response_wrapper,
)
from .._base_client import make_request_options

__all__ = ["PdfResource", "AsyncPdfResource"]


class PdfResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> PdfResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/legalesign/legalesign-rest-python#accessing-raw-response-data-eg-headers
        """
        return PdfResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> PdfResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/legalesign/legalesign-rest-python#with_streaming_response
        """
        return PdfResourceWithStreamingResponse(self)

    def retrieve(
        self,
        doc_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> BinaryAPIResponse:
        """
        Get the PDF for a signing document

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not doc_id:
            raise ValueError(f"Expected a non-empty value for `doc_id` but received {doc_id!r}")
        extra_headers = {"Accept": "application/pdf", **(extra_headers or {})}
        return self._get(
            f"/pdf/{doc_id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=BinaryAPIResponse,
        )

    def create_preview(
        self,
        *,
        group: str,
        is_signature_per_page: int,
        signature_type: int,
        signee_count: int,
        text: str,
        footer: str | Omit = omit,
        footer_height: int | Omit = omit,
        header: str | Omit = omit,
        header_height: int | Omit = omit,
        pdfheader: bool | Omit = omit,
        title: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> BinaryAPIResponse:
        """
        text/html document as pdf preview

        Args:
          signee_count: number of signers

          text: raw html

          pdfheader: Set to true to use group default

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "application/pdf", **(extra_headers or {})}
        return self._post(
            "/pdf/preview/",
            body=maybe_transform(
                {
                    "group": group,
                    "is_signature_per_page": is_signature_per_page,
                    "signature_type": signature_type,
                    "signee_count": signee_count,
                    "text": text,
                    "footer": footer,
                    "footer_height": footer_height,
                    "header": header,
                    "header_height": header_height,
                    "pdfheader": pdfheader,
                    "title": title,
                },
                pdf_create_preview_params.PdfCreatePreviewParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=BinaryAPIResponse,
        )


class AsyncPdfResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncPdfResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/legalesign/legalesign-rest-python#accessing-raw-response-data-eg-headers
        """
        return AsyncPdfResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncPdfResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/legalesign/legalesign-rest-python#with_streaming_response
        """
        return AsyncPdfResourceWithStreamingResponse(self)

    async def retrieve(
        self,
        doc_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncBinaryAPIResponse:
        """
        Get the PDF for a signing document

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not doc_id:
            raise ValueError(f"Expected a non-empty value for `doc_id` but received {doc_id!r}")
        extra_headers = {"Accept": "application/pdf", **(extra_headers or {})}
        return await self._get(
            f"/pdf/{doc_id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AsyncBinaryAPIResponse,
        )

    async def create_preview(
        self,
        *,
        group: str,
        is_signature_per_page: int,
        signature_type: int,
        signee_count: int,
        text: str,
        footer: str | Omit = omit,
        footer_height: int | Omit = omit,
        header: str | Omit = omit,
        header_height: int | Omit = omit,
        pdfheader: bool | Omit = omit,
        title: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncBinaryAPIResponse:
        """
        text/html document as pdf preview

        Args:
          signee_count: number of signers

          text: raw html

          pdfheader: Set to true to use group default

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "application/pdf", **(extra_headers or {})}
        return await self._post(
            "/pdf/preview/",
            body=await async_maybe_transform(
                {
                    "group": group,
                    "is_signature_per_page": is_signature_per_page,
                    "signature_type": signature_type,
                    "signee_count": signee_count,
                    "text": text,
                    "footer": footer,
                    "footer_height": footer_height,
                    "header": header,
                    "header_height": header_height,
                    "pdfheader": pdfheader,
                    "title": title,
                },
                pdf_create_preview_params.PdfCreatePreviewParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AsyncBinaryAPIResponse,
        )


class PdfResourceWithRawResponse:
    def __init__(self, pdf: PdfResource) -> None:
        self._pdf = pdf

        self.retrieve = to_custom_raw_response_wrapper(
            pdf.retrieve,
            BinaryAPIResponse,
        )
        self.create_preview = to_custom_raw_response_wrapper(
            pdf.create_preview,
            BinaryAPIResponse,
        )


class AsyncPdfResourceWithRawResponse:
    def __init__(self, pdf: AsyncPdfResource) -> None:
        self._pdf = pdf

        self.retrieve = async_to_custom_raw_response_wrapper(
            pdf.retrieve,
            AsyncBinaryAPIResponse,
        )
        self.create_preview = async_to_custom_raw_response_wrapper(
            pdf.create_preview,
            AsyncBinaryAPIResponse,
        )


class PdfResourceWithStreamingResponse:
    def __init__(self, pdf: PdfResource) -> None:
        self._pdf = pdf

        self.retrieve = to_custom_streamed_response_wrapper(
            pdf.retrieve,
            StreamedBinaryAPIResponse,
        )
        self.create_preview = to_custom_streamed_response_wrapper(
            pdf.create_preview,
            StreamedBinaryAPIResponse,
        )


class AsyncPdfResourceWithStreamingResponse:
    def __init__(self, pdf: AsyncPdfResource) -> None:
        self._pdf = pdf

        self.retrieve = async_to_custom_streamed_response_wrapper(
            pdf.retrieve,
            AsyncStreamedBinaryAPIResponse,
        )
        self.create_preview = async_to_custom_streamed_response_wrapper(
            pdf.create_preview,
            AsyncStreamedBinaryAPIResponse,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union
from typing_extensions import Required, Annotated, TypedDict

from .._types import Base64FileInput
from .._utils import PropertyInfo

__all__ = ["TemplatepdfCreateParams"]


class TemplatepdfCreateParams(TypedDict, total=False):
    group: Required[str]

    pdf_file: Required[Annotated[Union[str, Base64FileInput], PropertyInfo(format="base64")]]
    """base64 encoded PDF file data"""

    archive_upon_send: bool
    """archive PDF when sent"""

    process_tags: bool

    title: str

    user: str
    """assign to group member if not api user"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime

from .._models import BaseModel
from .permissions_enum import PermissionsEnum

__all__ = ["MemberResponse"]


class MemberResponse(BaseModel):
    created: Optional[datetime] = None

    group: Optional[str] = None

    modified: Optional[datetime] = None

    permission: Optional[PermissionsEnum] = None
    """Permissions options:

    - 1 - administrator
    - 2 - team docs visible, create & send
    - 3 - team docs visible, send only
    - 4 - no team sent docs visible, send only
    - 5 - no team docs visible, create & send
    - 6 - team docs visible, read only
    """

    resource_uri: Optional[str] = None

    user: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable, Optional
from typing_extensions import Literal, Required, TypedDict

from ..pdf_field_validation_enum import PdfFieldValidationEnum

__all__ = ["FieldCreateParams", "Body"]


class FieldCreateParams(TypedDict, total=False):
    body: Required[Iterable[Body]]


class Body(TypedDict, total=False):
    ax: Required[float]
    """% of page width - left vertical: 0 = left page edge, 1 = right page edge"""

    ay: Required[float]
    """% of page height - upper horizontal: 0 = top page edge, 1 = bottom page edge"""

    bx: Required[float]
    """% of page width - right vertical, 0 = left page edge, 1 = right page edge"""

    by: Required[float]
    """% of page height lower horizontal. 0 = top page edge, 1 = bottom page edge"""

    element_type: Required[Literal["signature", "initials", "text", "admin"]]
    """
    Must be one of the following: _ signature - signature field _ initials -
    initials field _ text - signer field (field for signer to complete) _ admin -
    sender field (field to complete by admin user when sending, use pdftext)
    """

    page: Required[int]
    """which page to place field on"""

    signer: Required[int]
    """1-indexed number of signer (witness+100) (approver+200)"""

    align: Optional[Literal[1, 2, 3]]
    """one of the following:

    - 1 - left
    - 2 - middle
    - 3 - right
    """

    fieldorder: Optional[int]
    """Ordering of fields as the signer progresses (top-down by if left blank)"""

    font_name: Literal["", "arial", "courier", "helvetica", "liberation", "verdana"]

    font_size: int

    hide_border: bool

    label: str
    """Help a signer/sender understand what to do with the form field"""

    label_extra: str
    """unused. more label if required"""

    logic_action: Literal[1, 2, 3]
    """
    offers options for more advanced forms 1 = One of a set of field - radio group 2
    = Sum a set of fields 3 = Conditional upon another field
    """

    logic_group: str
    """values to enable a given logic_action in the form"""

    map_to: str
    """custom data for form integrations"""

    optional: bool
    """Set true to allow field to be ignored"""

    options: str
    """Additional values for certain validation types."""

    substantive: bool
    """
    Set if field substantive to contract terms, if so will not let other sign till
    this field completed
    """

    validation: Optional[PdfFieldValidationEnum]
    """fields types and validations:

    - 1 - Email
    - 2 - yyyy/mm/dd
    - 3 - yy/mm/dd
    - 4 - dd/mm/yyyy
    - 5 - dd/mm/yy
    - 6 - mm/dd/yy
    - 7 - mm/dd/yy
    - 8 - yyyy.mm.dd
    - 9 - yy.mm.dd
    - 10 - dd.mm.yyyy
    - 11 - dd.mm.yy
    - 12 - mm.dd.yyyy
    - 13 - mm.dd.yy
    - 14 - yyyy-mm-dd
    - 15 - yy-mm-dd
    - 16 - dd-mm-yyyy
    - 17 - dd-mm-yy
    - 18 - mm-dd-yyyy
    - 19 - mm-dd-yy
    - 20 - Dropdown list, use options attribute for items
    - 24 - Checkbox tick/cross
    - 25 - Checkbox tick/blank
    - 26 - Checkbox cross/blank
    - 30 - yyyy/mm/dd (automatic)
    - 31 - yy/mm/dd (automatic)
    - 32 - dd/yy/yyyy (automatic)
    - 33 - dd/mm/yy (automatic)
    - 34 - mm/dd/yyyy (automatic)
    - 35 - mm/dd/yy (automatic)
    - 36 - yyyy.mm.dd (automatic)
    - 37 - yy.mm.dd (automatic)
    - 38 - dd.mm.yyyy (automatic)
    - 39 - dd.mm.yy (automatic)
    - 40 - mm.dd.yyyy (automatic)
    - 41 - mm.dd.yy (automatic)
    - 42 - yyyy-mm-dd (automatic)
    - 43 - yy-mm-dd (automatic)
    - 44 - dd-mm-yyyy (automatic)
    - 45 - dd-mm-yy (automatic)
    - 46 - mm-dd-yyyy (automatic)
    - 47 - mm-dd-yy (automatic)
    - 48 - d mmmmm yyyy (automatic)
    - 50 - Whole number
    - 51 - Number
    - 52 - Currency (2 decimals)
    - 53 - 1 number
    - 54 - 2 numbers
    - 55 - 3 numbers
    - 56 - 4 numbers
    - 57 - 5 numbers
    - 58 - 6 numbers
    - 59 - 7 numbers
    - 60 - 8 numbers
    - 61 - 9 numbers
    - 62 - 10 numbers
    - 63 - 11 numbers
    - 64 - 12 numbers
    - 65 - 1 characters (any text)
    - 66 - 2 characters (any text)
    - 67 - 3 characters (any text)
    - 68 - 4 characters (any text)
    - 69 - 5 characters (any text)
    - 70 - 6 characters (any text)
    - 71 - 7 characters (any text)
    - 72 - 8 characters (any text)
    - 73 - secret code, add code in options
    - 74 - file attach, append to email to signer
    - 75 - file attach, append to final PDF
    - 76 - file attach, zip with final PDF for internal use, but not signer
    - 77 - force to title caps
    - 78 - force to uppercase
    - 79 - force to lowercase
    - 80 - mm/yy
    - 81 - mm/yyyy
    - 82 - mm.yy
    - 83 - mm.yyyy
    - 84 - mm-yy
    - 85 - mm-yyyy
    - 90 - drawn field
    - 91 - countries list
    - 92 - honorifics list
    """

    value: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union

import httpx

from ..types import attachment_list_params, attachment_upload_params
from .._types import Body, Omit, Query, Headers, NoneType, NotGiven, Base64FileInput, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.attachment_response import AttachmentResponse
from ..types.attachment_list_response import AttachmentListResponse

__all__ = ["AttachmentResource", "AsyncAttachmentResource"]


class AttachmentResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AttachmentResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/legalesign/legalesign-rest-python#accessing-raw-response-data-eg-headers
        """
        return AttachmentResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AttachmentResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/legalesign/legalesign-rest-python#with_streaming_response
        """
        return AttachmentResourceWithStreamingResponse(self)

    def retrieve(
        self,
        attachment_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AttachmentResponse:
        """
        Get attachment

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not attachment_id:
            raise ValueError(f"Expected a non-empty value for `attachment_id` but received {attachment_id!r}")
        return self._get(
            f"/attachment/{attachment_id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AttachmentResponse,
        )

    def list(
        self,
        *,
        group: str | Omit = omit,
        limit: int | Omit = omit,
        offset: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AttachmentListResponse:
        """
        List attachments in your groups

        Args:
          group: Filter by a specific group

          limit: Length of dataset to return. Use with offset query to iterate through results.

          offset: Offset from start of dataset. Use with the limit query to iterate through
              dataset.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/attachment/",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "group": group,
                        "limit": limit,
                        "offset": offset,
                    },
                    attachment_list_params.AttachmentListParams,
                ),
            ),
            cast_to=AttachmentListResponse,
        )

    def delete(
        self,
        attachment_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Delete attachment

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not attachment_id:
            raise ValueError(f"Expected a non-empty value for `attachment_id` but received {attachment_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._delete(
            f"/attachment/{attachment_id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def upload(
        self,
        *,
        filename: str,
        group: str,
        pdf_file: Union[str, Base64FileInput],
        description: str | Omit = omit,
        user: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Upload PDF attachment

        Args:
          filename: Simple alphanumeric name ending .pdf

          group: URI of the group name

          pdf_file: Base64 encoded PDF file data, max size is a group setting, 5MB by default

          user: Assign to group member if not the api user

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/attachment/",
            body=maybe_transform(
                {
                    "filename": filename,
                    "group": group,
                    "pdf_file": pdf_file,
                    "description": description,
                    "user": user,
                },
                attachment_upload_params.AttachmentUploadParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncAttachmentResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncAttachmentResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/legalesign/legalesign-rest-python#accessing-raw-response-data-eg-headers
        """
        return AsyncAttachmentResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncAttachmentResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/legalesign/legalesign-rest-python#with_streaming_response
        """
        return AsyncAttachmentResourceWithStreamingResponse(self)

    async def retrieve(
        self,
        attachment_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AttachmentResponse:
        """
        Get attachment

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not attachment_id:
            raise ValueError(f"Expected a non-empty value for `attachment_id` but received {attachment_id!r}")
        return await self._get(
            f"/attachment/{attachment_id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AttachmentResponse,
        )

    async def list(
        self,
        *,
        group: str | Omit = omit,
        limit: int | Omit = omit,
        offset: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AttachmentListResponse:
        """
        List attachments in your groups

        Args:
          group: Filter by a specific group

          limit: Length of dataset to return. Use with offset query to iterate through results.

          offset: Offset from start of dataset. Use with the limit query to iterate through
              dataset.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/attachment/",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "group": group,
                        "limit": limit,
                        "offset": offset,
                    },
                    attachment_list_params.AttachmentListParams,
                ),
            ),
            cast_to=AttachmentListResponse,
        )

    async def delete(
        self,
        attachment_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Delete attachment

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not attachment_id:
            raise ValueError(f"Expected a non-empty value for `attachment_id` but received {attachment_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._delete(
            f"/attachment/{attachment_id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def upload(
        self,
        *,
        filename: str,
        group: str,
        pdf_file: Union[str, Base64FileInput],
        description: str | Omit = omit,
        user: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Upload PDF attachment

        Args:
          filename: Simple alphanumeric name ending .pdf

          group: URI of the group name

          pdf_file: Base64 encoded PDF file data, max size is a group setting, 5MB by default

          user: Assign to group member if not the api user

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/attachment/",
            body=await async_maybe_transform(
                {
                    "filename": filename,
                    "group": group,
                    "pdf_file": pdf_file,
                    "description": description,
                    "user": user,
                },
                attachment_upload_params.AttachmentUploadParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AttachmentResourceWithRawResponse:
    def __init__(self, attachment: AttachmentResource) -> None:
        self._attachment = attachment

        self.retrieve = to_raw_response_wrapper(
            attachment.retrieve,
        )
        self.list = to_raw_response_wrapper(
            attachment.list,
        )
        self.delete = to_raw_response_wrapper(
            attachment.delete,
        )
        self.upload = to_raw_response_wrapper(
            attachment.upload,
        )


class AsyncAttachmentResourceWithRawResponse:
    def __init__(self, attachment: AsyncAttachmentResource) -> None:
        self._attachment = attachment

        self.retrieve = async_to_raw_response_wrapper(
            attachment.retrieve,
        )
        self.list = async_to_raw_response_wrapper(
            attachment.list,
        )
        self.delete = async_to_raw_response_wrapper(
            attachment.delete,
        )
        self.upload = async_to_raw_response_wrapper(
            attachment.upload,
        )


class AttachmentResourceWithStreamingResponse:
    def __init__(self, attachment: AttachmentResource) -> None:
        self._attachment = attachment

        self.retrieve = to_streamed_response_wrapper(
            attachment.retrieve,
        )
        self.list = to_streamed_response_wrapper(
            attachment.list,
        )
        self.delete = to_streamed_response_wrapper(
            attachment.delete,
        )
        self.upload = to_streamed_response_wrapper(
            attachment.upload,
        )


class AsyncAttachmentResourceWithStreamingResponse:
    def __init__(self, attachment: AsyncAttachmentResource) -> None:
        self._attachment = attachment

        self.retrieve = async_to_streamed_response_wrapper(
            attachment.retrieve,
        )
        self.list = async_to_streamed_response_wrapper(
            attachment.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            attachment.delete,
        )
        self.upload = async_to_streamed_response_wrapper(
            attachment.upload,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Generic, TypeVar, Optional
from typing_extensions import override

from ._base_client import BasePage, PageInfo, BaseSyncPage, BaseAsyncPage

__all__ = ["SyncMyOffsetPage", "AsyncMyOffsetPage"]

_T = TypeVar("_T")


class SyncMyOffsetPage(BaseSyncPage[_T], BasePage[_T], Generic[_T]):
    objects: List[_T]
    meta: Optional[object] = None

    @override
    def _get_page_items(self) -> List[_T]:
        objects = self.objects
        if not objects:
            return []
        return objects

    @override
    def next_page_info(self) -> Optional[PageInfo]:
        offset = self._options.params.get("offset") or 0
        if not isinstance(offset, int):
            raise ValueError(f'Expected "offset" param to be an integer but got {offset}')

        length = len(self._get_page_items())
        current_count = offset + length

        return PageInfo(params={"offset": current_count})


class AsyncMyOffsetPage(BaseAsyncPage[_T], BasePage[_T], Generic[_T]):
    objects: List[_T]
    meta: Optional[object] = None

    @override
    def _get_page_items(self) -> List[_T]:
        objects = self.objects
        if not objects:
            return []
        return objects

    @override
    def next_page_info(self) -> Optional[PageInfo]:
        offset = self._options.params.get("offset") or 0
        if not isinstance(offset, int):
            raise ValueError(f'Expected "offset" param to be an integer but got {offset}')

        length = len(self._get_page_items())
        current_count = offset + length

        return PageInfo(params={"offset": current_count})
